(function (global, factory) {
    typeof exports === 'object' && typeof module !== 'undefined' ? factory(exports) :
    typeof define === 'function' && define.amd ? define(['exports'], factory) :
    (global = typeof globalThis !== 'undefined' ? globalThis : global || self, factory(global.lunarPhase = {}));
}(this, (function (exports) { 'use strict';

    /**
     * Earth's hemispheres.
     */
    exports.Hemisphere = void 0;
    (function (Hemisphere) {
        Hemisphere[Hemisphere["Northern"] = 0] = "Northern";
        Hemisphere[Hemisphere["Southern"] = 1] = "Southern";
    })(exports.Hemisphere || (exports.Hemisphere = {}));

    exports.Time = void 0;
    (function (Time) {
        /**
         * Timestamp epoch, January 1, 1970, in Julian Days.
         */
        Time.epoch = 2440587.5;
        /**
         * Lunation 1 as the first new moon of 1923 at approximately
         * 02:41 UTC, January 17, 1923 per Ernest William Brown's lunar theory.
         */
        Time.lunationBaseJulianDay = 2423436.6115277777;
        /**
         * Length of one phase (1/8 of a synodic month) in Earth days.
         */
        Time.phaseLength = 3.69132346322;
        /**
         * Length of one synodic month, or days for the phases to complete a cycle.
         * Time between two identical syzygies, equivalent of 29.53059 Earth days.
         *
         * Based on Mean Synodic Month, 2000 AD mean solar days.
         */
        Time.synodicMonthlength = 29.53058770576;
    })(exports.Time || (exports.Time = {}));

    exports.JulianDay = void 0;
    (function (JulianDay) {
        /**
         * Julian day from Gregorian date.
         * @param date - Gregorian date to convert to Julian day.
         */
        JulianDay.fromDate = (date = new Date()) => {
            const time = date.getTime();
            return time / 86400000 - date.getTimezoneOffset() / 1440 + exports.Time.epoch;
        };
        /**
         * Gregorian date from Julian day
         * @param julian - Julian dat to convert to Gregorian date
         */
        JulianDay.toDate = (julian) => {
            let date = new Date();
            date.setTime((julian - exports.Time.epoch + date.getTimezoneOffset() / 1440) * 86400000);
            return date;
        };
    })(exports.JulianDay || (exports.JulianDay = {}));

    /**
     * Enumeration of lunar phases as emoji.
     */
    exports.LunarEmoji = void 0;
    (function (LunarEmoji) {
        (function (NorthernHemisphere) {
            NorthernHemisphere["New"] = "\uD83C\uDF11";
            NorthernHemisphere["WaxingCrescent"] = "\uD83C\uDF12";
            NorthernHemisphere["FirstQuarter"] = "\uD83C\uDF13";
            NorthernHemisphere["WaxingGibbous"] = "\uD83C\uDF14";
            NorthernHemisphere["Full"] = "\uD83C\uDF15";
            NorthernHemisphere["WaningGibbous"] = "\uD83C\uDF16";
            NorthernHemisphere["LastQuarter"] = "\uD83C\uDF17";
            NorthernHemisphere["WaningCrescent"] = "\uD83C\uDF18";
        })(LunarEmoji.NorthernHemisphere || (LunarEmoji.NorthernHemisphere = {}));
        (function (SouthernHemisphere) {
            SouthernHemisphere["New"] = "\uD83C\uDF11";
            SouthernHemisphere["WaxingCrescent"] = "\uD83C\uDF18";
            SouthernHemisphere["FirstQuarter"] = "\uD83C\uDF17";
            SouthernHemisphere["WaxingGibbous"] = "\uD83C\uDF16";
            SouthernHemisphere["Full"] = "\uD83C\uDF15";
            SouthernHemisphere["WaningGibbous"] = "\uD83C\uDF14";
            SouthernHemisphere["LastQuarter"] = "\uD83C\uDF13";
            SouthernHemisphere["WaningCrescent"] = "\uD83C\uDF12";
        })(LunarEmoji.SouthernHemisphere || (LunarEmoji.SouthernHemisphere = {}));
    })(exports.LunarEmoji || (exports.LunarEmoji = {}));

    /**
     * Enumeration of lunar phases
     */
    exports.LunarPhase = void 0;
    (function (LunarPhase) {
        LunarPhase["New"] = "New";
        LunarPhase["WaxingCrescent"] = "Waxing Crescent";
        LunarPhase["FirstQuarter"] = "First Quarter";
        LunarPhase["WaxingGibbous"] = "Waxing Gibbous";
        LunarPhase["Full"] = "Full";
        LunarPhase["WaningGibbous"] = "Waning Gibbous";
        LunarPhase["LastQuarter"] = "Last Quarter";
        LunarPhase["WaningCrescent"] = "Waning Crescent";
    })(exports.LunarPhase || (exports.LunarPhase = {}));

    exports.Moon = void 0;
    (function (Moon) {
        /**
         * Moon's age, or Earth days since the last new moon.
         *
         * @param date - Date used for calculation.
         * @returns Age of the moon, normalized within a 29.53059 Earth days calendar.
         */
        Moon.lunarAge = (date = new Date()) => {
            const percent = Moon.lunarAgePercent(date);
            return percent * exports.Time.synodicMonthlength;
        };
        /**
         * Percentage through the lunar synodic month.
         *
         * @param date - Date used for calculation.
         * @returns Percentage through the lunar month.
         */
        Moon.lunarAgePercent = (date = new Date()) => {
            return Moon.normalize((exports.JulianDay.fromDate(date) - 2451550.1) / exports.Time.synodicMonthlength);
        };
        /**
         * Brown Lunation Number (BLN), per Ernest William Brown's lunar theory,
         * defining Lunation 1 as the first new moon of 1923 at
         * approximately 02:41 UTC, January 17, 1923
         *
         * @param date
         */
        Moon.lunationNumber = (date = new Date()) => {
            return Math.round((exports.JulianDay.fromDate(date) - exports.Time.lunationBaseJulianDay) / exports.Time.synodicMonthlength) + 1;
        };
        /**
         * Name of the lunar phase per date submitted.
         *
         * @param date - Date used to calculate lunar phase.
         * @returns Name as string of the current lunar phase.
         */
        Moon.lunarPhase = (date = new Date()) => {
            const age = Moon.lunarAge(date);
            if (age < 1.84566173161)
                return exports.LunarPhase.New;
            else if (age < 5.53698519483)
                return exports.LunarPhase.WaxingCrescent;
            else if (age < 9.22830865805)
                return exports.LunarPhase.FirstQuarter;
            else if (age < 12.91963212127)
                return exports.LunarPhase.WaxingGibbous;
            else if (age < 16.61095558449)
                return exports.LunarPhase.Full;
            else if (age < 20.30227904771)
                return exports.LunarPhase.WaningGibbous;
            else if (age < 23.99360251093)
                return exports.LunarPhase.LastQuarter;
            else if (age < 27.68492597415)
                return exports.LunarPhase.WaningCrescent;
            return exports.LunarPhase.New;
        };
        /**
         * Emoji of the lunar phase per date submitted.
         *
         * @param date - Date used to calculate lunar phase.
         * @param hemisphere - Northern or Southern Hemisphere.
         * @returns Emoji of the current lunar phase.
         */
        Moon.lunarPhaseEmoji = (date = new Date(), hemisphere = exports.Hemisphere.Northern) => {
            const phase = Moon.lunarPhase(date);
            return Moon.emojiForLunarPhase(phase, hemisphere);
        };
        /**
         * Emoji for specified lunar phase
         *
         * @param phase - Lunar phase, per the LunarPhase enum
         * @param hemisphere - Northern or Southern Hemisphere.
         * @returns Emoji of the current lunar phase.
         */
        Moon.emojiForLunarPhase = (phase, hemisphere = exports.Hemisphere.Northern) => {
            let emoji;
            if (hemisphere === exports.Hemisphere.Southern) {
                emoji = exports.LunarEmoji.NorthernHemisphere;
            }
            else {
                emoji = exports.LunarEmoji.SouthernHemisphere;
            }
            switch (phase) {
                case exports.LunarPhase.WaningCrescent:
                    return emoji["WaningCrescent"];
                case exports.LunarPhase.LastQuarter:
                    return emoji["LastQuarter"];
                case exports.LunarPhase.WaningGibbous:
                    return emoji["WaningGibbous"];
                case exports.LunarPhase.Full:
                    return emoji["Full"];
                case exports.LunarPhase.WaxingGibbous:
                    return emoji["WaxingGibbous"];
                case exports.LunarPhase.FirstQuarter:
                    return emoji["FirstQuarter"];
                case exports.LunarPhase.WaxingCrescent:
                    return emoji["WaxingCrescent"];
                default:
                case exports.LunarPhase.New:
                    return emoji["New"];
            }
        };
        /**
         * Whether the moon is currently waxing (growing).
         *
         * @param date - Date used for calculation.
         * @returns True if moon is waxing.
         */
        Moon.isWaxing = (date = new Date()) => {
            const age = Moon.lunarAge(date);
            return age <= 14.765;
        };
        /**
         * Whether the moon is currently waning (shrinking).
         *
         * @param date - Date used for calculation.
         * @returns True if moon is waning.
         */
        Moon.isWaning = (date = new Date()) => {
            const age = Moon.lunarAge(date);
            return age > 14.765;
        };
        /**
         * Normalization utility for percentage calculations.
         *
         * @param value - Percent value.
         */
        Moon.normalize = (value) => {
            value = value - Math.floor(value);
            if (value < 0)
                value = value + 1;
            return value;
        };
    })(exports.Moon || (exports.Moon = {}));

    Object.defineProperty(exports, '__esModule', { value: true });

})));
